pub struct DeclarativeGoal {
pub check: String,
pub max_iterations: u32,
}Expand description
Deterministic completion contract for a declarative agent invocation.
The daemon runs check in the same scratch worktree after each agent pass
and re-drives until it exits 0 or max_iterations is exhausted.
Fields
check: Stringmax_iterations: u32Trait Implementations
Sourceimpl Clone for DeclarativeGoal
impl Clone for DeclarativeGoal
Sourcefn clone(&self) -> DeclarativeGoal
fn clone(&self) -> DeclarativeGoal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeclarativeGoal
impl Debug for DeclarativeGoal
Sourceimpl<'de> Deserialize<'de> for DeclarativeGoal
impl<'de> Deserialize<'de> for DeclarativeGoal
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DeclarativeGoal, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DeclarativeGoal, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DeclarativeGoal
impl JsonSchema for DeclarativeGoal
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeclarativeGoal
impl PartialEq for DeclarativeGoal
Sourceimpl Serialize for DeclarativeGoal
impl Serialize for DeclarativeGoal
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for DeclarativeGoal