pub struct MutationLedger { /* private fields */ }Expand description
Latches once a mutating tool has succeeded, and never clears.
See the module docs on why this does not reset when the worktree is restored.
Implementations
Sourceimpl MutationLedger
impl MutationLedger
pub fn new() -> Self
Sourcepub fn record_mutation(&self)
pub fn record_mutation(&self)
Record that a mutating tool call succeeded. Idempotent, and one-way.
pub fn has_mutated(&self) -> bool